@@ -1,10 +1,10 @@
 #ifndef S7_H
 #define S7_H
 
-#define S7_VERSION "11.3"
-#define S7_DATE "10-Feb-2025"
+#define S7_VERSION "11.4"
+#define S7_DATE "15-Mar-2025"
 #define S7_MAJOR_VERSION 11
-#define S7_MINOR_VERSION 3
+#define S7_MINOR_VERSION 4
 
 #include <stdint.h>           /* for int64_t */
 
@@ -296,6 +296,7 @@ s7_double s7_number_to_real_with_caller(s7_scheme *sc, s7_pointer x, const char
 s7_double s7_number_to_real_with_location(s7_scheme *sc, s7_pointer x, s7_pointer caller);
 s7_int s7_number_to_integer(s7_scheme *sc, s7_pointer x);
 s7_int s7_number_to_integer_with_caller(s7_scheme *sc, s7_pointer x, const char *caller);
+char *s7_number_to_string(s7_scheme *sc, s7_pointer obj, s7_int radix);     /* (number->string obj radix) */
 
 bool s7_is_rational(s7_pointer arg);                                        /* (rational? arg) -- integer or ratio */
 bool s7_is_ratio(s7_pointer arg);                                           /* true if arg is a ratio, not an integer */
@@ -303,6 +304,7 @@ s7_pointer s7_make_ratio(s7_scheme *sc, s7_int a, s7_int b);                /* r
 s7_pointer s7_rationalize(s7_scheme *sc, s7_double x, s7_double error);     /* (rationalize x error) */
 s7_int s7_numerator(s7_pointer x);                                          /* (numerator x) */
 s7_int s7_denominator(s7_pointer x);                                        /* (denominator x) */
+
 s7_double s7_random(s7_scheme *sc, s7_pointer state);                       /* (random x) */
 s7_pointer s7_random_state(s7_scheme *sc, s7_pointer seed);                 /* (random-state seed) */
 s7_pointer s7_random_state_to_list(s7_scheme *sc, s7_pointer args);         /* (random-state->list r) */
@@ -313,49 +315,52 @@ bool s7_is_complex(s7_pointer arg);                                         /* (
 s7_pointer s7_make_complex(s7_scheme *sc, s7_double a, s7_double b);        /* returns the Scheme object a+bi */
 s7_double s7_real_part(s7_pointer z);                                       /* (real-part z) */
 s7_double s7_imag_part(s7_pointer z);                                       /* (imag-part z) */
-char *s7_number_to_string(s7_scheme *sc, s7_pointer obj, s7_int radix);     /* (number->string obj radix) */
 
 bool s7_is_vector(s7_pointer p);                                            /* (vector? p) */
-s7_int s7_vector_length(s7_pointer vec);                                    /* (vector-length vec) */
-s7_int s7_vector_rank(s7_pointer vect);                                     /* number of dimensions in vect */
-s7_int s7_vector_dimension(s7_pointer vec, s7_int dim);
-s7_pointer *s7_vector_elements(s7_pointer vec);                             /* a pointer to the array of s7_pointers */
-s7_int *s7_int_vector_elements(s7_pointer vec);
-uint8_t *s7_byte_vector_elements(s7_pointer vec);
-s7_double *s7_float_vector_elements(s7_pointer vec);
 bool s7_is_float_vector(s7_pointer p);                                      /* (float-vector? p) */
 bool s7_is_complex_vector(s7_pointer p);                                    /* (complex-vector? p) */
 bool s7_is_int_vector(s7_pointer p);                                        /* (int-vector? p) */
 bool s7_is_byte_vector(s7_pointer p);                                       /* (byte-vector? p) */
 
+s7_int s7_vector_length(s7_pointer vec);                                    /* (vector-length vec) */
+s7_int s7_vector_rank(s7_pointer vect);                                     /* number of dimensions in vect */
+s7_int s7_vector_dimension(s7_pointer vec, s7_int dim);
+s7_int s7_vector_dimensions(s7_pointer vec, s7_int *dims, s7_int dims_size); /* vector dimensions */
+s7_int s7_vector_offsets(s7_pointer vec, s7_int *offs, s7_int offs_size);
+
+s7_pointer *s7_vector_elements(s7_pointer vec);                             /* a pointer to the array of s7_pointers */
+s7_int *s7_int_vector_elements(s7_pointer vec);
+uint8_t *s7_byte_vector_elements(s7_pointer vec);
+s7_double *s7_float_vector_elements(s7_pointer vec);
+
 s7_pointer s7_vector_ref(s7_scheme *sc, s7_pointer vec, s7_int index);                            /* (vector-ref vec index) */
 s7_pointer s7_vector_set(s7_scheme *sc, s7_pointer vec, s7_int index, s7_pointer a);              /* (vector-set! vec index a) */
 s7_pointer s7_vector_ref_n(s7_scheme *sc, s7_pointer vector, s7_int indices, ...);                   /* multidimensional vector-ref */
 s7_pointer s7_vector_set_n(s7_scheme *sc, s7_pointer vector, s7_pointer value, s7_int indices, ...); /* multidimensional vector-set! */
-s7_int s7_vector_dimensions(s7_pointer vec, s7_int *dims, s7_int dims_size); /* vector dimensions */
-s7_int s7_vector_offsets(s7_pointer vec, s7_int *offs, s7_int offs_size);
-
-s7_int s7_int_vector_ref(s7_pointer vec, s7_int index);
-s7_int s7_int_vector_set(s7_pointer vec, s7_int index, s7_int value);
-uint8_t s7_byte_vector_ref(s7_pointer vec, s7_int index);
-uint8_t s7_byte_vector_set(s7_pointer vec, s7_int index, uint8_t value);
-s7_double s7_float_vector_ref(s7_pointer vec, s7_int index);
-s7_double s7_float_vector_set(s7_pointer vec, s7_int index, s7_double value);
-
 s7_pointer s7_make_vector(s7_scheme *sc, s7_int len);                                 /* (make-vector len) */
 s7_pointer s7_make_normal_vector(s7_scheme *sc, s7_int len, s7_int dims, s7_int *dim_info); /* make-vector but possibly multidimensional */
 s7_pointer s7_make_and_fill_vector(s7_scheme *sc, s7_int len, s7_pointer fill);       /* (make-vector len fill) */
+
+s7_int s7_int_vector_ref(s7_pointer vec, s7_int index);
+s7_int s7_int_vector_set(s7_pointer vec, s7_int index, s7_int value);
 s7_pointer s7_make_int_vector(s7_scheme *sc, s7_int len, s7_int dims, s7_int *dim_info);
+s7_pointer s7_make_int_vector_wrapper(s7_scheme *sc, s7_int len, s7_int *data, s7_int dims, s7_int *dim_info, bool free_data);
+
+uint8_t s7_byte_vector_ref(s7_pointer vec, s7_int index);
+uint8_t s7_byte_vector_set(s7_pointer vec, s7_int index, uint8_t value);
 s7_pointer s7_make_byte_vector(s7_scheme *sc, s7_int len, s7_int dims, s7_int *dim_info);
+
+s7_double s7_float_vector_ref(s7_pointer vec, s7_int index);
+s7_double s7_float_vector_set(s7_pointer vec, s7_int index, s7_double value);
 s7_pointer s7_make_float_vector(s7_scheme *sc, s7_int len, s7_int dims, s7_int *dim_info);
 s7_pointer s7_make_float_vector_wrapper(s7_scheme *sc, s7_int len, s7_double *data, s7_int dims, s7_int *dim_info, bool free_data);
 
 #if (!__TINYC__) && ((!defined(__clang__)) || (!__cplusplus))
-  s7_pointer s7_make_complex_vector(s7_scheme *sc, s7_int len, s7_int dims, s7_int *dim_info);
-  s7_pointer s7_make_complex_vector_wrapper(s7_scheme *sc, s7_int len, s7_complex *data, s7_int dims, s7_int *dim_info, bool free_data);
   s7_complex *s7_complex_vector_elements(s7_pointer vec);
   s7_complex s7_complex_vector_ref(s7_pointer vec, s7_int index);
   s7_complex s7_complex_vector_set(s7_pointer vec, s7_int index, s7_complex value);
+  s7_pointer s7_make_complex_vector(s7_scheme *sc, s7_int len, s7_int dims, s7_int *dim_info);
+  s7_pointer s7_make_complex_vector_wrapper(s7_scheme *sc, s7_int len, s7_complex *data, s7_int dims, s7_int *dim_info, bool free_data);
 #endif
 
 void s7_vector_fill(s7_scheme *sc, s7_pointer vec, s7_pointer obj);                   /* (vector-fill! vec obj) */
@@ -943,6 +948,7 @@ bool s7_is_bignum(s7_pointer obj);
  *
  *        s7 changes
  *
+ * 10-Mar-24: s7_make_int_vector_wrapper.
  * --------
  * 31-Dec:    s7_function_let as an experiment.
  * 31-Aug:    s7_define_expansion.
