@@ -12,23 +12,22 @@ void snd_help_back_to_top(void);
 
 /* -------- snd-xdraw.c -------- */
 
-void draw_line(axis_context *ax, int x0, int y0, int x1, int y1);
-void fill_rectangle(axis_context *ax, int x0, int y0, int width, int height);
-void erase_rectangle(chan_info *cp, axis_context *ax, int x0, int y0, int width, int height);
-void fill_polygon(axis_context *ax, int points, ...);
-void fill_polygons(axis_context *ax, point_t *points, int num, int y0);
-void fill_two_sided_polygons(axis_context *ax, point_t *points, point_t *points1, int num);
-void draw_polygon(axis_context *ax, int points, ...);
-void draw_string(axis_context *ax, int x0, int y0, const char *str, int len);
-void draw_dot(axis_context *ax, int x, int y, int size);
-void setup_axis_context(chan_info *cp, axis_context *ax);
-void draw_spectro_line(axis_context *ax, int color, int x0, int y0, int x1, int y1);
+void draw_line(graphics_context *ax, int x0, int y0, int x1, int y1);
+void fill_rectangle(graphics_context *ax, int x0, int y0, int width, int height);
+void erase_rectangle(chan_info *cp, graphics_context *ax, int x0, int y0, int width, int height);
+void fill_polygon(graphics_context *ax, int points, ...);
+void fill_polygons(graphics_context *ax, point_t *points, int num, int y0);
+void fill_two_sided_polygons(graphics_context *ax, point_t *points, point_t *points1, int num);
+void draw_string(graphics_context *ax, int x0, int y0, const char *str, int len);
+void draw_dot(graphics_context *ax, int x, int y, int size);
+void setup_graphics_context(chan_info *cp, graphics_context *ax);
+void draw_spectro_line(graphics_context *ax, int color, int x0, int y0, int x1, int y1);
 void allocate_color_map(int colormap);
 void allocate_sono_rects(int size);
 void set_sono_rectangle(int j, int color, int x, int y, int width, int height);
-void draw_sono_rectangles(axis_context *ax, int color, int jmax);
-void draw_colored_lines(chan_info *cp, axis_context *ax, point_t *points, int num, int *colors, int axis_y0, color_t default_color);
-widget_t start_color_orientation_dialog(bool managed);
+void draw_sono_rectangles(graphics_context *ax, int color, int jmax);
+void draw_colored_lines(chan_info *cp, graphics_context *ax, point_t *points, int num, int *colors, int axis_y0, color_t default_color);
+widget_t make_color_orientation_dialog(bool managed);
 void set_color_scale(mus_float_t val);
 void set_color_inverted(bool val);
 void set_color_cutoff(mus_float_t val);
@@ -46,7 +45,7 @@ void set_with_gl(bool val, bool dpys);
 
 /* -------- snd-xfind.c -------- */
 
-void set_find_dialog_label(const char *str);
+bool find_dialog_is_active(void);
 void save_find_dialog_state(FILE *fd);
 
 
@@ -54,7 +53,6 @@ void save_find_dialog_state(FILE *fd);
 
 void append_listener_text(int end, const char *msg);
 int save_listener_text(FILE *fp);
-void listener_delete_text(int new_end);
 void listener_append_and_prompt(const char *msg);
 void goto_listener(void);
 void listener_append(const char *msg);
@@ -63,16 +61,18 @@ bool listener_exists(void);
 int listener_height(void);
 int listener_width(void);
 void clear_listener(void);
-bool highlight_unbalanced_paren(void);
 
 
 /* -------- snd-xmenu.c -------- */
 
 void check_menu_labels(int key, int state, bool extended);
-void reflect_play_stop_in_popup_menu(void);
 void reflect_play_selection_stop(void);
 int menu_widget(int which_menu);
 void set_button_label(int label, const char *str);
+void post_basic_popup_menu(void *ev);
+void post_lisp_popup_menu(void *ev);
+void post_fft_popup_menu(void *ev);
+void post_selection_popup_menu(void *ev);
 
 
 
@@ -91,7 +91,7 @@ void set_fft_window_alpha(mus_float_t val);
 void set_transform_size(mus_long_t val);
 void set_fft_window(mus_fft_window_t val);
 void set_wavelet_type(int val);
-int fire_up_transform_dialog(bool managed);
+int make_transform_dialog(bool managed);
 bool transform_dialog_is_active(void);
 void set_transform_type(int val);
 void set_show_transform_peaks(bool val);
@@ -113,7 +113,7 @@ void make_transform_type_list(void);
 
 /* -------- snd-xregion.c -------- */
 
-void update_region_browser(bool grf_too);
+int update_region_browser(bool grf_too);
 bool region_browser_is_active(void);
 void delete_region_and_update_browser(int n);
 void reflect_play_region_stop(int n);
@@ -138,7 +138,7 @@ int number_width(const char *num, bool use_tiny_font);
 int number_height(int fnt);
 int label_height(bool use_tiny_font);
 int mark_name_width(const char *txt);
-void clear_window(axis_context *ax);
+void clear_window(graphics_context *ax);
 void set_title(const char *title);
 void check_for_event(void);
 void recolor_graph(chan_info *cp, bool selected);
@@ -173,16 +173,12 @@ void resize_sx_and_zx(chan_info *cp);
 void channel_open_pane(chan_info *cp);
 void reflect_edit_history_change(chan_info *cp);
 void reflect_edit_counter_change(chan_info *cp);
-void set_peak_numbers_font(chan_info *cp);
-void set_bold_peak_numbers_font(chan_info *cp);
-void set_tiny_numbers_font(chan_info *cp);
-color_t get_foreground_color(axis_context *ax);
-void set_foreground_color(axis_context *ax, int color);
-void free_fft_pix(chan_info *cp);
-bool restore_fft_pix(chan_info *cp, axis_context *ax);
-void save_fft_pix(chan_info *cp, axis_context *ax, int fwidth, int fheight, int x0, int y1);
+void set_peak_numbers_font(chan_info *cp, graphics_context *ax);
+void set_bold_peak_numbers_font(chan_info *cp, graphics_context *ax);
+void set_tiny_numbers_font(chan_info *cp, graphics_context *ax);
+color_t get_foreground_color(graphics_context *ax);
+void set_foreground_color(graphics_context *ax, int color);
 void cleanup_cw(chan_info *cp);
-bool fixup_cp_cgx_ax_wn(chan_info *cp);
 void get_current_color(int colormap, int j, rgb_t *r, rgb_t *g, rgb_t *b);
 void change_channel_style(snd_info *sp, channel_style_t new_style);
 int add_channel_window(snd_info *sound, int channel, int chan_y, int insertion, widget_t main, fw_button_t arrows, bool with_events);
@@ -190,11 +186,7 @@ int add_channel_window(snd_info *sound, int channel, int chan_y, int insertion,
 
 /* -------- snd-xsnd.c -------- */
 
-void make_minibuffer_label(snd_info *sp, const char *str);
-void goto_minibuffer(snd_info *sp);
-void set_minibuffer_string(snd_info *sp, const char *str, bool update);
-void set_minibuffer_cursor_position(snd_info *sp, int pos);
-char *get_minibuffer_string(snd_info *sp);
+void set_status(snd_info *sp, const char *str, bool update);
 void snd_info_cleanup(snd_info *sp);
 void set_amp(snd_info *sp, mus_float_t val);
 void set_expand(snd_info *sp, mus_float_t val);
@@ -220,8 +212,6 @@ void show_lock(snd_info *sp);
 void hide_lock(snd_info *sp);
 void start_bomb(snd_info *sp);
 void stop_bomb(snd_info *sp);
-void show_bomb(snd_info *sp);
-void hide_bomb(snd_info *sp);
 snd_info *add_sound_window(char *filename, read_only_t read_only, file_info *hdr);
 void set_sound_pane_file_label(snd_info *sp, const char *str);
 void show_controls(snd_info *sp);
@@ -231,19 +221,19 @@ void start_progress_report(chan_info *cp);
 void finish_progress_report(chan_info *cp);
 void progress_report(chan_info *cp, mus_float_t pct);
 void reflect_sound_selection(snd_info *sp);
-void display_minibuffer_error(snd_info *sp, const char *str);
-void clear_minibuffer_error(snd_info *sp);
-
+void update_sound_label(snd_info *sp);
 
 /* -------- snd-xfile.c -------- */
 
-char *get_file_dialog_sound_attributes(file_data *fdat, int *srate, int *chans, int *type, int *format, mus_long_t *location, mus_long_t *samples, int min_chan);
-void alert_new_file(void);
+void cleanup_file_monitor(void);
+void *unmonitor_file(void *watcher);
+void monitor_sound(snd_info *sp);
+
+char *get_file_dialog_sound_attributes(file_data *fdat, int *srate, int *chans, mus_header_t *header_type, 
+				       mus_sample_t *sample_type, mus_long_t *location, mus_long_t *samples, int min_chan);
 widget_t make_new_file_dialog(bool managed);
 int edit_header(snd_info *sp);
 void save_edit_header_dialog_state(FILE *fd);
-void cleanup_edit_header_watcher(void);
-void cleanup_new_file_watcher(void);
 widget_t make_open_file_dialog(read_only_t read_only, bool managed);
 void set_open_file_play_button(bool val);
 widget_t make_selection_save_as_dialog(bool managed);
@@ -251,16 +241,19 @@ widget_t make_region_save_as_dialog(bool managed);
 widget_t make_sound_save_as_dialog(bool managed);
 widget_t make_mix_file_dialog(bool managed);
 widget_t make_insert_file_dialog(bool managed);
-void clear_deleted_snd_info(struct dialog_play_info *dp);
 widget_t post_it(const char *subject, const char *str);
 void save_post_it_dialog_state(FILE *fd);
 void reflect_just_sounds(void);
 void save_file_dialog_state(FILE *fd);
+void reflect_selection_in_save_as_dialog(bool on);
+void reflect_save_as_src(bool val);
+void reflect_save_as_auto_comment(bool val);
+void reflect_save_as_sound_selection(const char *sound_name);
 
 
 /* -------- snd-xenv.c -------- */
 
-axis_info *enved_make_axis(const char *name, axis_context *ax, int ex0, int ey0, int width, int height, 
+axis_info *enved_make_axis(const char *name, graphics_context *ax, int ex0, int ey0, int width, int height, 
 			   mus_float_t xmin, mus_float_t xmax, mus_float_t ymin, mus_float_t ymax, printing_t printing);
 void display_enved_env_with_selection(env *e, const char *name, int x0, int y0, int width, int height, bool dots, printing_t printing);
 void set_enved_redo_sensitive(bool val);
@@ -268,6 +261,7 @@ void set_enved_revert_sensitive(bool val);
 void set_enved_undo_sensitive(bool val);
 void set_enved_save_sensitive(bool val);
 void set_enved_show_sensitive(bool val);
+void enved_reflect_selection(bool on);
 void make_scrolled_env_list(void);
 void enved_reflect_peak_env_completion(snd_info *sp);
 void new_active_channel_alert(void);
@@ -275,11 +269,11 @@ void env_redisplay(void);
 void env_redisplay_with_print(void);
 void update_enved_background_waveform(chan_info *cp);
 int create_envelope_editor(void);
-void set_enved_clip_p(bool val);
+void set_enved_clipping(bool val);
 void reflect_enved_style(void);
 void set_enved_base(mus_float_t val);
 void set_enved_target(enved_target_t val);
-void set_enved_wave_p(bool val);
+void set_enved_with_wave(bool val);
 void set_enved_in_dB(bool val);
 bool enved_dialog_is_active(void);
 void set_enved_filter_order(int order);
@@ -296,21 +290,14 @@ void mix_dialog_set_mix(int id);
 
 
 
-/* -------- snd-xrec.c -------- */
-
-widget_t record_file(void);
-
-
-
 /* -------- snd-xprint.c -------- */
 
 widget_t make_file_print_dialog(bool managed, bool direct_to_printer);
-void save_print_dialog_state(FILE *fd);
 
 
 /* -------- snd-xprefs.c -------- */
 
-widget_t start_preferences_dialog(void);
+widget_t make_preferences_dialog(void);
 
 #endif
 
