@@ -150,7 +150,6 @@
 
 (freq-test)
 
-
 ;;;; --------------------------------------------------------------------------------
 
 (define (string-split char-delimiter? string)
@@ -556,7 +555,6 @@
     ((= i 4))
   (output-fern-as-eps "barnsley.eps" (create-fern 0 0 50000)))
 
-
 ;;; --------------------------------------------------------------------------------
 
 ;;; circles through 2 points
@@ -611,11 +609,10 @@
 
 (test-circles)
 
-
 ;;; --------------------------------------------------------------------------------
 
 ;;; compare strings
-(define (compare-strings fn strs)
+(define-constant (compare-strings fn strs)
   (or (null? strs)                             ; returns #t on empty list
       (null? (cdr strs))                       ; returns #t on list of size 1
       (do ((fst strs (cdr fst))
@@ -633,7 +630,6 @@
 
 (test-compare)
 
-
 ;;; --------------------------------------------------------------------------------
 
 ;;; ordered words unixdict.txt
@@ -704,7 +700,6 @@
 
 (fringe)
 
-
 ;;; --------------------------------------------------------------------------------
 
 ;;; vector products
@@ -848,7 +843,6 @@
 
 (test-heap)
 
-
 ;;; --------------------------------------------------------------------------------
 
 ;;; sierpinski carpet
@@ -905,7 +899,6 @@
 (test-babbage)
 ;; 25264
 
-
 ;;; --------------------------------------------------------------------------------
 
 ;;; longest increasing subsequence
