@@ -17,14 +17,14 @@
 		  *unbound-variable-hook* *load-hook* *rootlet-redefinition-hook* *missing-close-paren-hook* *read-error-hook*
 		  tree-count ; signature is kinda silly here
 		  c-define-1 apropos map-values trace-in profile-in
-		  define-expansion
+		  define-expansion substring-uncopied ; this because errmsg has "substring" not "substring-uncopied"
 		  heap-scan heap-analyze heap-holders heap-holder
 		  check check-funcs type-ok
 		  show-stack trace-in profile-in apply call-with-exit
 		  define-expansion call-with-current-continuation 
 		  vector-append append ; append gets uninteresting type conversion complaints
 		  call/cc call-with-output-string open-input-function open-output-function
-		  set-current-input-port ;set-current-output-port 
+		  set-current-input-port ;set-current-output-port
 		  set-current-error-port))
 
 (let ((max-args 3))
@@ -40,7 +40,7 @@
 					'((1 2) (3 4)) '((1 (2)) (((3) 4))) "" (list #i(1) "1") '(1 2 . 3) (list (cons 'a 2) (cons 'b 3))
 					#i(1 2) (vector 1 '(3)) (let ((x 3)) (lambda (y) (+ x y))) abs 'a 'b one
 					(lambda args args) (lambda* ((a 3) (b 2)) (+ a b)) (lambda () 3)
-					(sublet () 'a 1) ;(rootlet)
+					(sublet (rootlet) 'a 1)
 					*load-hook*  *error-hook* 
 					(random-state 123)
 					quasiquote macroexpand begin let letrec* if case cond (call-with-exit (lambda (goto) goto))
@@ -80,7 +80,7 @@
 	     (lambda (type info)
 	       (if (and (positive? args-now)
 			(memq type '(wrong-type-arg wrong-number-of-args out-of-range syntax-error io-error
-				     division-by-zero format-error missing-method error invalid-escape-function)))
+				     division-by-zero format-error missing-method error invalid-exit-function)))
 		   (quit)))))
        
        (let ((c-args (vector-ref auto-arglists args-now)))
@@ -88,7 +88,7 @@
 	 
 	 (let ((p (list-tail c-args args-now))
 	       (checker (and (pair? sig) (car sig)))) ; see map-values
-	   
+
 	   (if (= args-left 1)
 	       (call-with-exit
 		(lambda (quit)
@@ -99,7 +99,7 @@
 		      (apply func c-args))
 		    (lambda (type info)
 		      (if (or (memq type '(wrong-number-of-args out-of-range syntax-error io-error
-					   division-by-zero format-error error missing-method invalid-escape-function))
+					   division-by-zero format-error error missing-method invalid-exit-function))
 			      (and (eq? type 'wrong-type-arg)
 				   (pair? (cdr info))
 				   (pair? (cddr info))
