@@ -10,13 +10,23 @@
     (load "snd-motif.scm"))
 
 (define xe-envelope
-  (dilambda
-   (lambda (editor)
-     (or (car editor) 
-	 (map (editor 3) '(0 1 2 3)))) ; bounds
-   (lambda (editor new-env)
-     (set! (editor 0) new-env)
-     (xe-redraw editor))))
+  (let ((check-x (lambda (coords) ; make sure time marches forward (8-Feb-24)
+		   (if (not (pair? coords))
+		       coords
+		       (let ((x0 (car coords)))
+			 (do ((x (cddr coords) (cddr x)))
+			     ((null? x) coords)
+			   (let ((x1 (car x)))
+			     (if (<= x1 x0)
+				 (set-car! x (+ x0 1.0e-8)))
+			     (set! x0 (car x)))))))))
+    (dilambda
+     (lambda (editor)
+       (or (check-x (car editor))
+	   (map (editor 3) '(0 1 2 3)))) ; bounds
+     (lambda (editor new-env)
+       (set! (editor 0) new-env)
+       (xe-redraw editor)))))
 
 (define xe-create-enved 
   (let ((xe-ungrfy (lambda (editor y)
